@@ -7,22 +7,28 @@
 #    The essential reference for computational positional astronomy.
 #
 
-__version__ = "2.0.3"
+__version__ = "2.0.3.1"
 
 __all__ = [
     'holidays', 'astro', 'utils', 'bahai',
     'french_republican', 'gregorian', 'hebrew',
     'indian_civil', 'islamic', 'iso',
-    'julian', 'mayan', 'persian', 'mayan'
+    'julian', 'mayan', 'persian', 'mayan',
+    'ordinal',
 ]
 
 from . import bahai
+from . import dublin
 from . import french_republican
 from . import gregorian
 from . import hebrew
+from . import holidays
 from . import indian_civil
 from . import islamic
 from . import julian
+from . import julianday
 from . import mayan
 from . import persian
 from . import mayan
+from . import ordinal
+
