@@ -1,12 +1,23 @@
 # -*- coding: utf-8 -*-
-from .utils import floor
-from calendar import isleap as leap
+from .utils import floor, monthcalendarhelper, jwday
+from calendar import isleap as leap, monthrange
+
 
 EPOCH = 1721425.5
 
+INTERCALATION_CYCLE_YEARS = 400
+INTERCALATION_CYCLE_DAYS = 146097
+
+LEAP_SUPPRESSION_YEARS = 100
+LEAP_SUPPRESSION_DAYS = 36524
+
+LEAP_CYCLE_YEARS = 4
+LEAP_CYCLE_DAYS = 1461
+
 HAVE_30_DAYS = (4, 6, 9, 11)
 HAVE_31_DAYS = (1, 3, 5, 7, 8, 10, 12)
 
+
 def legal_date(year, month, day):
     '''Check if this is a legal date in the Gregorian calendar'''
     if month == 2:
@@ -19,6 +30,7 @@ def legal_date(year, month, day):
 
     return True
 
+
 def to_jd2(year, month, day):
     '''Gregorian to Julian Day Count for years between 1801-2099'''
     # http://quasar.as.utexas.edu/BillInfo/JulianDatesG.html
@@ -38,7 +50,6 @@ def to_jd2(year, month, day):
 
 
 def to_jd(year, month, day):
-
     legal_date(year, month, day)
 
     if month <= 2:
@@ -59,23 +70,33 @@ def from_jd(jd):
     '''Return Gregorian date in a (Y, M, D) tuple'''
     wjd = floor(jd - 0.5) + 0.5
     depoch = wjd - EPOCH
-    quadricent = floor(depoch / 146097)
-    dqc = depoch % 146097
-    cent = floor(dqc / 36524)
-    dcent = dqc % 36524
-    quad = floor(dcent / 1461)
-    dquad = dcent % 1461
+
+    quadricent = floor(depoch / INTERCALATION_CYCLE_DAYS)
+    dqc = depoch % INTERCALATION_CYCLE_DAYS
+
+    cent = floor(dqc / LEAP_SUPPRESSION_DAYS)
+    dcent = dqc % LEAP_SUPPRESSION_DAYS
+
+    quad = floor(dcent / LEAP_CYCLE_DAYS)
+    dquad = dcent % LEAP_CYCLE_DAYS
+
     yindex = floor(dquad / 365)
-    year = (quadricent * 400) + (cent * 100) + (quad * 4) + yindex
+    year = (
+        quadricent * INTERCALATION_CYCLE_YEARS +
+        cent * LEAP_SUPPRESSION_YEARS +
+        quad * LEAP_CYCLE_YEARS + yindex
+    )
 
     if not (cent == 4 or yindex == 4):
         year += 1
 
     yearday = wjd - to_jd(year, 1, 1)
 
-    if wjd < to_jd(year, 3, 1):
+    isleap = leap(year)
+
+    if yearday < 58 + isleap:
         leap_adj = 0
-    elif leap(year):
+    elif isleap:
         leap_adj = 1
     else:
         leap_adj = 2
@@ -85,3 +106,13 @@ def from_jd(jd):
 
     return (year, month, day)
 
+
+def month_length(year, month):
+    return monthrange(year, month)[1]
+
+
+def monthcalendar(year, month):
+    start_weekday = jwday(to_jd(year, month, 1))
+    monthlen = month_length(year, month)
+
+    return monthcalendarhelper(start_weekday, monthlen)
